photoshop.save\_options package
===============================

Submodules
----------

photoshop.save\_options.bmp module
----------------------------------

.. automodule:: photoshop.save_options.bmp
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.save\_options.eps module
----------------------------------

.. automodule:: photoshop.save_options.eps
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.save\_options.gif module
----------------------------------

.. automodule:: photoshop.save_options.gif
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.save\_options.jpg module
----------------------------------

.. automodule:: photoshop.save_options.jpg
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.save\_options.pdf module
----------------------------------

.. automodule:: photoshop.save_options.pdf
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.save\_options.png module
----------------------------------

.. automodule:: photoshop.save_options.png
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.save\_options.psd module
----------------------------------

.. automodule:: photoshop.save_options.psd
   :members:
   :undoc-members:
   :show-inheritance:

photoshop.save\_options.tif module
----------------------------------

.. automodule:: photoshop.save_options.tif
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: photoshop.save_options
   :members:
   :undoc-members:
   :show-inheritance:
